#include <libint2.h>
#include <GenericContract.h>
#include <OSVRRP0InBra_aB_p__0__i__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP0InBra_aB_p__0__k__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP0InBra_aB_p__0__l__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP0InBra_aB_p__0__m__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP0InBra_aB_p__0__pp__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP0InBra_aB_p__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__m__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__pp__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0.h>

#ifdef __cplusplus
extern "C" {
#endif
void _aB_P__0__I__1___TwoPRep_S__0__H__1___Ab__up_0_prereq(const Libint_t* inteval, LIBINT2_REALTYPE* parent_stack) {

LIBINT2_REALTYPE*const  stack = parent_stack;
{
const int hsi = 0;
{
const int lsi = 0;
{
const int vi = 0;
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+924)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_3[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_4[vi]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+927)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_2[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_3[vi]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+930)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_4[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_5[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+933)*1+lsi)*1]), &(stack[((hsi*3+924)*1+lsi)*1]), &(stack[((hsi*3+930)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_3[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_4[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+939)*1+lsi)*1]), &(stack[((hsi*3+927)*1+lsi)*1]), &(stack[((hsi*3+924)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_2[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_3[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+945)*1+lsi)*1]), &(stack[((hsi*6+939)*1+lsi)*1]), &(stack[((hsi*6+933)*1+lsi)*1]), &(stack[((hsi*3+927)*1+lsi)*1]), &(stack[((hsi*3+924)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+955)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_1[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_2[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+958)*1+lsi)*1]), &(stack[((hsi*3+955)*1+lsi)*1]), &(stack[((hsi*3+927)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_1[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_2[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+964)*1+lsi)*1]), &(stack[((hsi*6+958)*1+lsi)*1]), &(stack[((hsi*6+939)*1+lsi)*1]), &(stack[((hsi*3+955)*1+lsi)*1]), &(stack[((hsi*3+927)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+927)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_5[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_6[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+974)*1+lsi)*1]), &(stack[((hsi*3+930)*1+lsi)*1]), &(stack[((hsi*3+927)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_4[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_5[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+980)*1+lsi)*1]), &(stack[((hsi*6+933)*1+lsi)*1]), &(stack[((hsi*6+974)*1+lsi)*1]), &(stack[((hsi*3+924)*1+lsi)*1]), &(stack[((hsi*3+930)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+990)*1+lsi)*1]), &(stack[((hsi*10+945)*1+lsi)*1]), &(stack[((hsi*10+980)*1+lsi)*1]), &(stack[((hsi*6+939)*1+lsi)*1]), &(stack[((hsi*6+933)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+1005)*1+lsi)*1]), &(stack[((hsi*10+964)*1+lsi)*1]), &(stack[((hsi*10+945)*1+lsi)*1]), &(stack[((hsi*6+958)*1+lsi)*1]), &(stack[((hsi*6+939)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+1020)*1+lsi)*1]), &(stack[((hsi*15+1005)*1+lsi)*1]), &(stack[((hsi*15+990)*1+lsi)*1]), &(stack[((hsi*10+964)*1+lsi)*1]), &(stack[((hsi*10+945)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+924)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_6[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_7[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+939)*1+lsi)*1]), &(stack[((hsi*3+927)*1+lsi)*1]), &(stack[((hsi*3+924)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_5[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_6[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+1041)*1+lsi)*1]), &(stack[((hsi*6+974)*1+lsi)*1]), &(stack[((hsi*6+939)*1+lsi)*1]), &(stack[((hsi*3+930)*1+lsi)*1]), &(stack[((hsi*3+927)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+1051)*1+lsi)*1]), &(stack[((hsi*10+980)*1+lsi)*1]), &(stack[((hsi*10+1041)*1+lsi)*1]), &(stack[((hsi*6+933)*1+lsi)*1]), &(stack[((hsi*6+974)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+1066)*1+lsi)*1]), &(stack[((hsi*15+990)*1+lsi)*1]), &(stack[((hsi*15+1051)*1+lsi)*1]), &(stack[((hsi*10+945)*1+lsi)*1]), &(stack[((hsi*10+980)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+1087)*1+lsi)*1]), &(stack[((hsi*21+1020)*1+lsi)*1]), &(stack[((hsi*21+1066)*1+lsi)*1]), &(stack[((hsi*15+1005)*1+lsi)*1]), &(stack[((hsi*15+990)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+945)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_0[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_1[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+930)*1+lsi)*1]), &(stack[((hsi*3+945)*1+lsi)*1]), &(stack[((hsi*3+955)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_0[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_1[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+1115)*1+lsi)*1]), &(stack[((hsi*6+930)*1+lsi)*1]), &(stack[((hsi*6+958)*1+lsi)*1]), &(stack[((hsi*3+945)*1+lsi)*1]), &(stack[((hsi*3+955)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+1125)*1+lsi)*1]), &(stack[((hsi*10+1115)*1+lsi)*1]), &(stack[((hsi*10+964)*1+lsi)*1]), &(stack[((hsi*6+930)*1+lsi)*1]), &(stack[((hsi*6+958)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+1140)*1+lsi)*1]), &(stack[((hsi*15+1125)*1+lsi)*1]), &(stack[((hsi*15+1005)*1+lsi)*1]), &(stack[((hsi*10+1115)*1+lsi)*1]), &(stack[((hsi*10+964)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+945)*1+lsi)*1]), &(stack[((hsi*21+1140)*1+lsi)*1]), &(stack[((hsi*21+1020)*1+lsi)*1]), &(stack[((hsi*15+1125)*1+lsi)*1]), &(stack[((hsi*15+1005)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*84+1161)*1+lsi)*1]), &(stack[((hsi*28+945)*1+lsi)*1]), &(stack[((hsi*28+1087)*1+lsi)*1]), &(stack[((hsi*21+1020)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*84+0)*1+lsi)*1]),&(stack[((hsi*84+1161)*1+lsi)*1]),84);
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1115)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_7[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_8[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1118)*1+lsi)*1]), &(stack[((hsi*3+924)*1+lsi)*1]), &(stack[((hsi*3+1115)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_6[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_7[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+1124)*1+lsi)*1]), &(stack[((hsi*6+939)*1+lsi)*1]), &(stack[((hsi*6+1118)*1+lsi)*1]), &(stack[((hsi*3+927)*1+lsi)*1]), &(stack[((hsi*3+924)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+1005)*1+lsi)*1]), &(stack[((hsi*10+1041)*1+lsi)*1]), &(stack[((hsi*10+1124)*1+lsi)*1]), &(stack[((hsi*6+974)*1+lsi)*1]), &(stack[((hsi*6+939)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+1245)*1+lsi)*1]), &(stack[((hsi*15+1051)*1+lsi)*1]), &(stack[((hsi*15+1005)*1+lsi)*1]), &(stack[((hsi*10+980)*1+lsi)*1]), &(stack[((hsi*10+1041)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+1266)*1+lsi)*1]), &(stack[((hsi*21+1066)*1+lsi)*1]), &(stack[((hsi*21+1245)*1+lsi)*1]), &(stack[((hsi*15+990)*1+lsi)*1]), &(stack[((hsi*15+1051)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+1294)*1+lsi)*1]), &(stack[((hsi*28+1087)*1+lsi)*1]), &(stack[((hsi*28+1266)*1+lsi)*1]), &(stack[((hsi*21+1020)*1+lsi)*1]), &(stack[((hsi*21+1066)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+1330)*1+lsi)*1]), &(stack[((hsi*28+945)*1+lsi)*1]), &(stack[((hsi*28+1087)*1+lsi)*1]), &(stack[((hsi*21+1140)*1+lsi)*1]), &(stack[((hsi*21+1020)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*108+1366)*1+lsi)*1]), &(stack[((hsi*36+1330)*1+lsi)*1]), &(stack[((hsi*36+1294)*1+lsi)*1]), &(stack[((hsi*28+1087)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*108+84)*1+lsi)*1]),&(stack[((hsi*108+1366)*1+lsi)*1]),108);
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+973)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_8[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_9[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+976)*1+lsi)*1]), &(stack[((hsi*3+1115)*1+lsi)*1]), &(stack[((hsi*3+973)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_7[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_8[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+1134)*1+lsi)*1]), &(stack[((hsi*6+1118)*1+lsi)*1]), &(stack[((hsi*6+976)*1+lsi)*1]), &(stack[((hsi*3+924)*1+lsi)*1]), &(stack[((hsi*3+1115)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+924)*1+lsi)*1]), &(stack[((hsi*10+1124)*1+lsi)*1]), &(stack[((hsi*10+1134)*1+lsi)*1]), &(stack[((hsi*6+939)*1+lsi)*1]), &(stack[((hsi*6+1118)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+1020)*1+lsi)*1]), &(stack[((hsi*15+1005)*1+lsi)*1]), &(stack[((hsi*15+924)*1+lsi)*1]), &(stack[((hsi*10+1041)*1+lsi)*1]), &(stack[((hsi*10+1124)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+1474)*1+lsi)*1]), &(stack[((hsi*21+1245)*1+lsi)*1]), &(stack[((hsi*21+1020)*1+lsi)*1]), &(stack[((hsi*15+1051)*1+lsi)*1]), &(stack[((hsi*15+1005)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+1502)*1+lsi)*1]), &(stack[((hsi*28+1266)*1+lsi)*1]), &(stack[((hsi*28+1474)*1+lsi)*1]), &(stack[((hsi*21+1066)*1+lsi)*1]), &(stack[((hsi*21+1245)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*45+1041)*1+lsi)*1]), &(stack[((hsi*36+1294)*1+lsi)*1]), &(stack[((hsi*36+1502)*1+lsi)*1]), &(stack[((hsi*28+1087)*1+lsi)*1]), &(stack[((hsi*28+1266)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*45+1538)*1+lsi)*1]), &(stack[((hsi*36+1330)*1+lsi)*1]), &(stack[((hsi*36+1294)*1+lsi)*1]), &(stack[((hsi*28+945)*1+lsi)*1]), &(stack[((hsi*28+1087)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*135+1583)*1+lsi)*1]), &(stack[((hsi*45+1538)*1+lsi)*1]), &(stack[((hsi*45+1041)*1+lsi)*1]), &(stack[((hsi*36+1294)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*135+192)*1+lsi)*1]),&(stack[((hsi*135+1583)*1+lsi)*1]),135);
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+939)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_9[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_10[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+942)*1+lsi)*1]), &(stack[((hsi*3+973)*1+lsi)*1]), &(stack[((hsi*3+939)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_8[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_9[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+1086)*1+lsi)*1]), &(stack[((hsi*6+976)*1+lsi)*1]), &(stack[((hsi*6+942)*1+lsi)*1]), &(stack[((hsi*3+1115)*1+lsi)*1]), &(stack[((hsi*3+973)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+948)*1+lsi)*1]), &(stack[((hsi*10+1134)*1+lsi)*1]), &(stack[((hsi*10+1086)*1+lsi)*1]), &(stack[((hsi*6+1118)*1+lsi)*1]), &(stack[((hsi*6+976)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+1096)*1+lsi)*1]), &(stack[((hsi*15+924)*1+lsi)*1]), &(stack[((hsi*15+948)*1+lsi)*1]), &(stack[((hsi*10+1124)*1+lsi)*1]), &(stack[((hsi*10+1134)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+1718)*1+lsi)*1]), &(stack[((hsi*21+1020)*1+lsi)*1]), &(stack[((hsi*21+1096)*1+lsi)*1]), &(stack[((hsi*15+1005)*1+lsi)*1]), &(stack[((hsi*15+924)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+982)*1+lsi)*1]), &(stack[((hsi*28+1474)*1+lsi)*1]), &(stack[((hsi*28+1718)*1+lsi)*1]), &(stack[((hsi*21+1245)*1+lsi)*1]), &(stack[((hsi*21+1020)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*45+1746)*1+lsi)*1]), &(stack[((hsi*36+1502)*1+lsi)*1]), &(stack[((hsi*36+982)*1+lsi)*1]), &(stack[((hsi*28+1266)*1+lsi)*1]), &(stack[((hsi*28+1474)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*55+1791)*1+lsi)*1]), &(stack[((hsi*45+1041)*1+lsi)*1]), &(stack[((hsi*45+1746)*1+lsi)*1]), &(stack[((hsi*36+1294)*1+lsi)*1]), &(stack[((hsi*36+1502)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*55+1846)*1+lsi)*1]), &(stack[((hsi*45+1538)*1+lsi)*1]), &(stack[((hsi*45+1041)*1+lsi)*1]), &(stack[((hsi*36+1330)*1+lsi)*1]), &(stack[((hsi*36+1294)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*165+1901)*1+lsi)*1]), &(stack[((hsi*55+1846)*1+lsi)*1]), &(stack[((hsi*55+1791)*1+lsi)*1]), &(stack[((hsi*45+1041)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*165+327)*1+lsi)*1]),&(stack[((hsi*165+1901)*1+lsi)*1]),165);
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1245)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_10[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_11[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1248)*1+lsi)*1]), &(stack[((hsi*3+939)*1+lsi)*1]), &(stack[((hsi*3+1245)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_9[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_10[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+963)*1+lsi)*1]), &(stack[((hsi*6+942)*1+lsi)*1]), &(stack[((hsi*6+1248)*1+lsi)*1]), &(stack[((hsi*3+973)*1+lsi)*1]), &(stack[((hsi*3+939)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+1254)*1+lsi)*1]), &(stack[((hsi*10+1086)*1+lsi)*1]), &(stack[((hsi*10+963)*1+lsi)*1]), &(stack[((hsi*6+976)*1+lsi)*1]), &(stack[((hsi*6+942)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+1269)*1+lsi)*1]), &(stack[((hsi*15+948)*1+lsi)*1]), &(stack[((hsi*15+1254)*1+lsi)*1]), &(stack[((hsi*10+1134)*1+lsi)*1]), &(stack[((hsi*10+1086)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+1290)*1+lsi)*1]), &(stack[((hsi*21+1096)*1+lsi)*1]), &(stack[((hsi*21+1269)*1+lsi)*1]), &(stack[((hsi*15+924)*1+lsi)*1]), &(stack[((hsi*15+948)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+1318)*1+lsi)*1]), &(stack[((hsi*28+1718)*1+lsi)*1]), &(stack[((hsi*28+1290)*1+lsi)*1]), &(stack[((hsi*21+1020)*1+lsi)*1]), &(stack[((hsi*21+1096)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*45+2066)*1+lsi)*1]), &(stack[((hsi*36+982)*1+lsi)*1]), &(stack[((hsi*36+1318)*1+lsi)*1]), &(stack[((hsi*28+1474)*1+lsi)*1]), &(stack[((hsi*28+1718)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*55+2111)*1+lsi)*1]), &(stack[((hsi*45+1746)*1+lsi)*1]), &(stack[((hsi*45+2066)*1+lsi)*1]), &(stack[((hsi*36+1502)*1+lsi)*1]), &(stack[((hsi*36+982)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*66+2166)*1+lsi)*1]), &(stack[((hsi*55+1791)*1+lsi)*1]), &(stack[((hsi*55+2111)*1+lsi)*1]), &(stack[((hsi*45+1041)*1+lsi)*1]), &(stack[((hsi*45+1746)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*66+2232)*1+lsi)*1]), &(stack[((hsi*55+1846)*1+lsi)*1]), &(stack[((hsi*55+1791)*1+lsi)*1]), &(stack[((hsi*45+1538)*1+lsi)*1]), &(stack[((hsi*45+1041)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*198+2298)*1+lsi)*1]), &(stack[((hsi*66+2232)*1+lsi)*1]), &(stack[((hsi*66+2166)*1+lsi)*1]), &(stack[((hsi*55+1791)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*198+492)*1+lsi)*1]),&(stack[((hsi*198+2298)*1+lsi)*1]),198);
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1474)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_11[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_12[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1477)*1+lsi)*1]), &(stack[((hsi*3+1245)*1+lsi)*1]), &(stack[((hsi*3+1474)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_10[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_11[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+1483)*1+lsi)*1]), &(stack[((hsi*6+1248)*1+lsi)*1]), &(stack[((hsi*6+1477)*1+lsi)*1]), &(stack[((hsi*3+939)*1+lsi)*1]), &(stack[((hsi*3+1245)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+1493)*1+lsi)*1]), &(stack[((hsi*10+963)*1+lsi)*1]), &(stack[((hsi*10+1483)*1+lsi)*1]), &(stack[((hsi*6+942)*1+lsi)*1]), &(stack[((hsi*6+1248)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+1508)*1+lsi)*1]), &(stack[((hsi*15+1254)*1+lsi)*1]), &(stack[((hsi*15+1493)*1+lsi)*1]), &(stack[((hsi*10+1086)*1+lsi)*1]), &(stack[((hsi*10+963)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+1018)*1+lsi)*1]), &(stack[((hsi*21+1269)*1+lsi)*1]), &(stack[((hsi*21+1508)*1+lsi)*1]), &(stack[((hsi*15+948)*1+lsi)*1]), &(stack[((hsi*15+1254)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+1474)*1+lsi)*1]), &(stack[((hsi*28+1290)*1+lsi)*1]), &(stack[((hsi*28+1018)*1+lsi)*1]), &(stack[((hsi*21+1096)*1+lsi)*1]), &(stack[((hsi*21+1269)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*45+1245)*1+lsi)*1]), &(stack[((hsi*36+1318)*1+lsi)*1]), &(stack[((hsi*36+1474)*1+lsi)*1]), &(stack[((hsi*28+1718)*1+lsi)*1]), &(stack[((hsi*28+1290)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*55+1018)*1+lsi)*1]), &(stack[((hsi*45+2066)*1+lsi)*1]), &(stack[((hsi*45+1245)*1+lsi)*1]), &(stack[((hsi*36+982)*1+lsi)*1]), &(stack[((hsi*36+1318)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*66+1245)*1+lsi)*1]), &(stack[((hsi*55+2111)*1+lsi)*1]), &(stack[((hsi*55+1018)*1+lsi)*1]), &(stack[((hsi*45+1746)*1+lsi)*1]), &(stack[((hsi*45+2066)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__pp__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*78+924)*1+lsi)*1]), &(stack[((hsi*66+2166)*1+lsi)*1]), &(stack[((hsi*66+1245)*1+lsi)*1]), &(stack[((hsi*55+1791)*1+lsi)*1]), &(stack[((hsi*55+2111)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__pp__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*78+1002)*1+lsi)*1]), &(stack[((hsi*66+2232)*1+lsi)*1]), &(stack[((hsi*66+2166)*1+lsi)*1]), &(stack[((hsi*55+1846)*1+lsi)*1]), &(stack[((hsi*55+1791)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__pp__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*234+2496)*1+lsi)*1]), &(stack[((hsi*78+1002)*1+lsi)*1]), &(stack[((hsi*78+924)*1+lsi)*1]), &(stack[((hsi*66+2166)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*234+690)*1+lsi)*1]),&(stack[((hsi*234+2496)*1+lsi)*1]),234);
}
}
}
const int hsi = 0;
const int lsi = 0;
const int vi = 0;
/** Number of flops = 924 */
}

#ifdef __cplusplus
};
#endif
